==> xpsql-0.9.1b.tar.gz: XpSQL/xpsql.h <==
/**
 - xpsql.h,v 1.1 2003/07/17 14:10:45 myui Exp
 */

#ifndef __XPSQL__
#define __XPSQL__

#include "postgres.h"			/* for DatumGetInt32 */
#include "fmgr.h"				/* for PG_GETARG_DATUM */

// NODE-TYPE and NUMBER BINDING
#define KIND_ROOT       0
#define KIND_ELEMENT    1
#define KIND_TEXT       2
#define KIND_COMMENT    3
#define KIND_PI         4
#define KIND_ATTRIBUTE  5
#define KIND_NAMESPACE  6
#define KIND_DUMMY		-1

// xpsql Revision Code
#define __XPSQL_REVISION__ "0.9"

#define SUCCESS (0==0)
#define FAILURE (0!=0)
#define SQL_QUERY_SUCCESS  0
#define SQL_QUERY_FAILURE -1

int exec_query(char *);
Datum create_new_document(PG_FUNCTION_ARGS);
Datum xml_tagid(PG_FUNCTION_ARGS);
Datum xml_attid(PG_FUNCTION_ARGS);
Datum xml_nsid(PG_FUNCTION_ARGS);
Datum xml_piid(PG_FUNCTION_ARGS);
Datum drop_document(PG_FUNCTION_ARGS);
Datum get_tagid(PG_FUNCTION_ARGS);
Datum get_attid(PG_FUNCTION_ARGS);
Datum get_nsid(PG_FUNCTION_ARGS);
Datum get_piid(PG_FUNCTION_ARGS);
Datum createelement(PG_FUNCTION_ARGS);
Datum createprocessinginstruction(PG_FUNCTION_ARGS);
Datum createtextnode(PG_FUNCTION_ARGS);
Datum createcomment(PG_FUNCTION_ARGS);
Datum new_childelement(PG_FUNCTION_ARGS);
Datum new_childpi(PG_FUNCTION_ARGS);
Datum new_childtext(PG_FUNCTION_ARGS);
Datum new_childcomment(PG_FUNCTION_ARGS);
Datum setattribute(PG_FUNCTION_ARGS);
Datum setnamespace(PG_FUNCTION_ARGS);
Datum appendchild(PG_FUNCTION_ARGS);
Datum insertbefore(PG_FUNCTION_ARGS);
Datum stringvalue(PG_FUNCTION_ARGS);
static int StrReplace(char *, const char *, const char *);
#endif/* __XPSQL__ */

==> xpsql-0.9.2.tar.gz: XpSQL/xpsql.h <==
/**
 - xpsql.h,v 1.1 2003/07/17 14:10:45 myui Exp
 */

#ifndef __XPSQL__
#define __XPSQL__

#include "postgres.h"			/* for DatumGetInt32 */
#include "fmgr.h"				/* for PG_GETARG_DATUM */

// NODE-TYPE and NUMBER BINDING
#define KIND_ROOT       0
#define KIND_ELEMENT    1
#define KIND_TEXT       2
#define KIND_COMMENT    3
#define KIND_PI         4
#define KIND_ATTRIBUTE  5
#define KIND_NAMESPACE  6
#define KIND_DUMMY		-1

// xpsql Revision Code
#define __XPSQL_REVISION__ "0.9"

#define SUCCESS (0==0)
#define FAILURE (0!=0)
#define SQL_QUERY_SUCCESS  0
#define SQL_QUERY_FAILURE -1

int exec_query(char *);
int execp_query(char *, int, Oid *, Datum *, char *, char);
Datum create_new_document(PG_FUNCTION_ARGS);
Datum xml_tagid(PG_FUNCTION_ARGS);
Datum xml_attid(PG_FUNCTION_ARGS);
Datum xml_nsid(PG_FUNCTION_ARGS);
Datum xml_piid(PG_FUNCTION_ARGS);
Datum drop_document(PG_FUNCTION_ARGS);
Datum get_tagid(PG_FUNCTION_ARGS);
Datum get_attid(PG_FUNCTION_ARGS);
Datum get_nsid(PG_FUNCTION_ARGS);
Datum get_piid(PG_FUNCTION_ARGS);
Datum createelement(PG_FUNCTION_ARGS);
Datum createprocessinginstruction(PG_FUNCTION_ARGS);
Datum createtextnode(PG_FUNCTION_ARGS);
Datum createcomment(PG_FUNCTION_ARGS);
Datum new_childelement(PG_FUNCTION_ARGS);
Datum new_childpi(PG_FUNCTION_ARGS);
Datum new_childtext(PG_FUNCTION_ARGS);
Datum new_childcomment(PG_FUNCTION_ARGS);
Datum setattribute(PG_FUNCTION_ARGS);
Datum setnamespace(PG_FUNCTION_ARGS);
Datum appendchild(PG_FUNCTION_ARGS);
Datum insertbefore(PG_FUNCTION_ARGS);
Datum stringvalue(PG_FUNCTION_ARGS);
Datum toxml(PG_FUNCTION_ARGS);
static int StrReplace(char *, const char *, const char *);

typedef struct
{
	char	   *ident;	// identifier
	void	  *splan;	// entity
	//int nplans; /* for the case argument type is not static. */
}	EPlan;

/* select plan */
static EPlan *sPlans = NULL;		// array of plans
static int	n_sPlans = 0;			// count plans
/* other plan */
static EPlan *oPlans = NULL;		// array of plans
static int	n_oPlans = 0;			// count plans

static EPlan *find_plan(char *, EPlan **, int *);
static void create_plan(EPlan **, char *, int, Oid *);

#endif/* __XPSQL__ */
